"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.BootstrapConstructor = void 0;
/**
 * BootstrapConstructor is a class that is used to create instances of classes.(this helps with dependency injection & mocking).
 */
class BootstrapConstructor {
    /**
     * Creates an instance of a class with a constructor.
     * @param typeConstructor The class constructor
     * @param constructorArguments The arguments to pass to the constructor(optional)
     * @returns The instance of the class
     */
    createInstance(typeConstructor, constructorArguments) {
        return new typeConstructor(...(constructorArguments || []));
    }
    /**
     * Creates an instance of a class without a constructor asynchronously.
     * @param typeConstructorFunction The class constructor ASYNC function.
     * @param constructorFunctionArguments the arguments to pass to the constructor(optional)
     * @returns The instance of the class
     */
    createAsyncInstanceWithoutConstructor(typeConstructorFunction, constructorFunctionArguments) {
        return __awaiter(this, void 0, void 0, function* () {
            return yield typeConstructorFunction(...(constructorFunctionArguments || []));
        });
    }
    /**
     * Creates an instance of a class without a constructor.
     * @param typeConstructorFunction The class constructor function.
     * @param constructorFunctionArguments the arguments to pass to the constructor(optional)
     * @returns The instance of the class
     */
    createInstanceWithoutConstructor(typeConstructorFunction, constructorFunctionArguments) {
        return typeConstructorFunction(...(constructorFunctionArguments || []));
    }
}
exports.BootstrapConstructor = BootstrapConstructor;
//# sourceMappingURL=bootstrap-constructor.js.map